'''Apport package hook for the ubiquity live CD installer.

Copyright (C) 2009 Canonical Ltd.
Authors: Colin Watson <cjwatson@ubuntu.com>,
         Brian Murray <brian@ubuntu.com>'''

import apport.hookutils
import os.path
import re

def add_installation_log(report, ident, name):
    if os.path.exists('/var/log/installer/%s' % name):
        f = '/var/log/installer/%s' % name
    elif os.path.exists('/var/log/%s' % name):
        f = '/var/log/%s' % name
    else:
        return

    if os.access(f, os.R_OK):
        report[ident] = open(f, 'r').read()
    elif os.path.exists(f):
        apport.hookutils.attach_root_command_outputs(report,
            {ident: "cat '%s'" % f})

def add_info(report, ui):
    add_installation_log(report, 'UbiquitySyslog', 'syslog')
    syslog = report['UbiquitySyslog']
    if 'Buffer I/O error on device' in syslog:
        if not re.search('Attached .* CD-ROM (\w+)', syslog):
            continue
        cd_drive = re.search('Attached .* CD-ROM (\w+)', syslog).group(1)
        cd_error = re.search('Buffer I/O error on device %s' % cd_drive,
            syslog)
        if cd_error:
            ui.information("The system log from your installation contains an error.  The specific error commonly occurs when there is an issue with the media from which you were installing.  This can happen when your media is dirty or damaged or when you've burned the media at a high speed.  Please try cleaning the media and or burning new media at a lower speed.  In the event that you continue to encounter these errors it may be an issue with your CD / DVD drive.")
            raise StopIteration
    if 'SQUASHFS error: Unable to read' in syslog:
        ui.information("The system log from your installation contains an error.  The specific error commonly occurs when there is an issue with the media from which you were installing.  This can happen when your media is dirty or damaged or when you've burned the media at a high speed.  Please try cleaning the media and or burning new media at a lower speed.  In the event that you continue to encounter these errors it may be an issue with your CD / DVD drive.")
        raise StopIteration

    match = re.search('ubiquity.*Ubiquity (.*)\n', report['UbiquitySyslog'])
    if match:
        match = match.group(1)
    report.setdefault('Tags', '')
    if match and 'oem-config' in match:
        version = match.split()[0]
        report['Tags'] += ' oem-config'
    elif match:
        version = match
    report['Tags'] += ' ubiquity-%s' % version

    add_installation_log(report, 'UbiquityPartman', 'partman')
    if os.path.exists('/var/log/installer/debug'):
        response = ui.yesno("The debug log file from your installation would help us a lot but includes the password you used for your user when installing Ubuntu.  Do you want to include this log file?")
        if response is None:
            raise StopIteration
        if response:
            add_installation_log(report, 'UbiquityDebug', 'debug')
    add_installation_log(report, 'UbiquityDm', 'dm')
    add_installation_log(report, 'Casper', 'casper.log')
    add_installation_log(report, 'OemConfigLog', 'oem-config.log')
